@@ -36,6 +36,7 @@ class HashClient(object):
         socket_module=socket,
         key_prefix=b'',
         max_pool_size=None,
+        pool_idle_timeout=0,
         lock_generator=None,
         retry_attempts=2,
         retry_timeout=1,
@@ -104,6 +105,7 @@ class HashClient(object):
         if use_pooling is True:
             self.default_kwargs.update({
                 'max_pool_size': max_pool_size,
+                'pool_idle_timeout': pool_idle_timeout,
                 'lock_generator': lock_generator
             })
 
@@ -112,6 +114,11 @@ class HashClient(object):
         self.encoding = encoding
         self.tls_context = tls_context
 
+    def _make_client_key(self, server):
+        if isinstance(server, (list, tuple)) and len(server) == 2:
+            return '%s:%s' % server
+        return server
+
     def add_server(self, server, port=None):
         # To maintain backward compatibility, if a port is provided, assume
         # that server wasn't provided as a (host, port) tuple.
@@ -120,16 +127,12 @@ class HashClient(object):
                 raise TypeError('Server must be a string when passing port.')
             server = (server, port)
 
-        if isinstance(server, six.string_types):
-            key = server
-        else:
-            key = '%s:%s' % server
-
         _class = PooledClient if self.use_pooling else self.client_class
         client = _class(server, **self.default_kwargs)
         if self.use_pooling:
             client.client_class = self.client_class
 
+        key = self._make_client_key(server)
         self.clients[key] = client
         self.hasher.add_node(key)
 
@@ -141,11 +144,7 @@ class HashClient(object):
                 raise TypeError('Server must be a string when passing port.')
             server = (server, port)
 
-        if isinstance(server, six.string_types):
-            key = server
-        else:
-            key = '%s:%s' % server
-
+        key = self._make_client_key(server)
         dead_time = time.time()
         self._failed_clients.pop(server)
         self._dead_clients[server] = dead_time
@@ -181,8 +180,7 @@ class HashClient(object):
                 return
             raise MemcacheError('All servers seem to be down right now')
 
-        client = self.clients[server]
-        return client
+        return self.clients[server]
 
     def _safely_run_func(self, client, func, default_val, *args, **kwargs):
         try:
@@ -340,15 +338,12 @@ class HashClient(object):
         succeeded = []
 
         try:
-            for key, value in six.iteritems(values):
-                result = client.set(key, value, *args, **kwargs)
-                if result:
-                    succeeded.append(key)
-                else:
-                    failed.append(key)
+            failed = client.set_many(values, *args, **kwargs)
         except Exception as e:
-            return succeeded, failed, e
+            if not self.ignore_exc:
+                return succeeded, failed, e
 
+        succeeded = [key for key in six.iterkeys(values) if key not in failed]
         return succeeded, failed, None
 
     def close(self):
@@ -383,8 +378,7 @@ class HashClient(object):
             client_batches[client.server][key] = value
 
         for server, values in client_batches.items():
-            client = self.clients['%s:%s' % server]
-
+            client = self.clients[self._make_client_key(server)]
             failed += self._safely_run_set_many(
                 client, values, *args, **kwargs
             )
@@ -406,7 +400,7 @@ class HashClient(object):
             client_batches[client.server].append(key)
 
         for server, keys in client_batches.items():
-            client = self.clients['%s:%s' % server]
+            client = self.clients[self._make_client_key(server)]
             new_args = list(args)
             new_args.insert(0, keys)
 
